==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/ZookeeperClusterSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorageFluent;
import java.util.LinkedHashMap;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorage;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.storage.SingleVolumeStorage;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import io.strimzi.api.kafka.model.storage.EphemeralStorageBuilder;
import java.lang.Object;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplateBuilder;
import io.strimzi.api.kafka.model.storage.EphemeralStorage;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorageBuilder;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplate;
import java.lang.StringBuffer;
import io.strimzi.api.kafka.model.storage.EphemeralStorageFluent;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplateFluent;

public interface ZookeeperClusterSpecFluent<A extends ZookeeperClusterSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildStorage instead.
 * @return The buildable object.
 */
@Deprecated public SingleVolumeStorage getStorage();
    public SingleVolumeStorage buildStorage();
    public A withStorage(SingleVolumeStorage storage);
    public Boolean hasStorage();
    public A withPersistentClaimStorage(PersistentClaimStorage persistentClaimStorage);
    public ZookeeperClusterSpecFluent.PersistentClaimStorageNested<A> withNewPersistentClaimStorage();
    public ZookeeperClusterSpecFluent.PersistentClaimStorageNested<A> withNewPersistentClaimStorageLike(PersistentClaimStorage item);
    public A withEphemeralStorage(EphemeralStorage ephemeralStorage);
    public ZookeeperClusterSpecFluent.EphemeralStorageNested<A> withNewEphemeralStorage();
    public ZookeeperClusterSpecFluent.EphemeralStorageNested<A> withNewEphemeralStorageLike(EphemeralStorage item);
    public A addToConfig(String key,Object value);
    public A addToConfig(Map<String,Object> map);
    public A removeFromConfig(String key);
    public A removeFromConfig(Map<String,Object> map);
    public Map<String,Object> getConfig();
    public A withConfig(Map<String,Object> config);
    public Boolean hasConfig();
    
/**
 * This method has been deprecated, please use method buildLogging instead.
 * @return The buildable object.
 */
@Deprecated public Logging getLogging();
    public Logging buildLogging();
    public A withLogging(Logging logging);
    public Boolean hasLogging();
    public A withExternalLogging(ExternalLogging externalLogging);
    public ZookeeperClusterSpecFluent.ExternalLoggingNested<A> withNewExternalLogging();
    public ZookeeperClusterSpecFluent.ExternalLoggingNested<A> withNewExternalLoggingLike(ExternalLogging item);
    public A withInlineLogging(InlineLogging inlineLogging);
    public ZookeeperClusterSpecFluent.InlineLoggingNested<A> withNewInlineLogging();
    public ZookeeperClusterSpecFluent.InlineLoggingNested<A> withNewInlineLoggingLike(InlineLogging item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecar instead.
 * @return The buildable object.
 */
@Deprecated public TlsSidecar getTlsSidecar();
    public TlsSidecar buildTlsSidecar();
    public A withTlsSidecar(TlsSidecar tlsSidecar);
    public Boolean hasTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> withNewTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> withNewTlsSidecarLike(TlsSidecar item);
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecarLike(TlsSidecar item);
    public int getReplicas();
    public A withReplicas(int replicas);
    public Boolean hasReplicas();
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public A withNewImage(String arg1);
    public A withNewImage(StringBuilder arg1);
    public A withNewImage(StringBuffer arg1);
    public ResourceRequirements getResources();
    public A withResources(ResourceRequirements resources);
    public Boolean hasResources();
    
/**
 * This method has been deprecated, please use method buildLivenessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getLivenessProbe();
    public Probe buildLivenessProbe();
    public A withLivenessProbe(Probe livenessProbe);
    public Boolean hasLivenessProbe();
    public A withNewLivenessProbe(int initialDelaySeconds,int timeoutSeconds);
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> withNewLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> withNewLivenessProbeLike(Probe item);
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildReadinessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getReadinessProbe();
    public Probe buildReadinessProbe();
    public A withReadinessProbe(Probe readinessProbe);
    public Boolean hasReadinessProbe();
    public A withNewReadinessProbe(int initialDelaySeconds,int timeoutSeconds);
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> withNewReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> withNewReadinessProbeLike(Probe item);
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildJvmOptions instead.
 * @return The buildable object.
 */
@Deprecated public JvmOptions getJvmOptions();
    public JvmOptions buildJvmOptions();
    public A withJvmOptions(JvmOptions jvmOptions);
    public Boolean hasJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> withNewJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> withNewJvmOptionsLike(JvmOptions item);
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editOrNewJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editOrNewJvmOptionsLike(JvmOptions item);
    public A addToMetrics(String key,Object value);
    public A addToMetrics(Map<String,Object> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,Object> map);
    public Map<String,Object> getMetrics();
    public A withMetrics(Map<String,Object> metrics);
    public Boolean hasMetrics();
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public ZookeeperClusterTemplate getTemplate();
    public ZookeeperClusterTemplate buildTemplate();
    public A withTemplate(ZookeeperClusterTemplate template);
    public Boolean hasTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> withNewTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> withNewTemplateLike(ZookeeperClusterTemplate item);
    public ZookeeperClusterSpecFluent.TemplateNested<A> editTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> editOrNewTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> editOrNewTemplateLike(ZookeeperClusterTemplate item);

    public interface PersistentClaimStorageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentClaimStorageFluent<ZookeeperClusterSpecFluent.PersistentClaimStorageNested<N>>{

        
    public N and();    public N endPersistentClaimStorage();
}
    public interface EphemeralStorageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EphemeralStorageFluent<ZookeeperClusterSpecFluent.EphemeralStorageNested<N>>{

        
    public N and();    public N endEphemeralStorage();
}
    public interface ExternalLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalLoggingFluent<ZookeeperClusterSpecFluent.ExternalLoggingNested<N>>{

        
    public N and();    public N endExternalLogging();
}
    public interface InlineLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InlineLoggingFluent<ZookeeperClusterSpecFluent.InlineLoggingNested<N>>{

        
    public N and();    public N endInlineLogging();
}
    public interface TlsSidecarNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsSidecarFluent<ZookeeperClusterSpecFluent.TlsSidecarNested<N>>{

        
    public N and();    public N endTlsSidecar();
}
    public interface LivenessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<ZookeeperClusterSpecFluent.LivenessProbeNested<N>>{

        
    public N and();    public N endLivenessProbe();
}
    public interface ReadinessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<ZookeeperClusterSpecFluent.ReadinessProbeNested<N>>{

        
    public N and();    public N endReadinessProbe();
}
    public interface JvmOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JvmOptionsFluent<ZookeeperClusterSpecFluent.JvmOptionsNested<N>>{

        
    public N and();    public N endJvmOptions();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ZookeeperClusterTemplateFluent<ZookeeperClusterSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/ZookeeperClusterSpecFluent.java <==
package io.strimzi.api.kafka.model;

import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorageFluent;
import java.util.LinkedHashMap;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorage;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.strimzi.api.kafka.model.storage.SingleVolumeStorage;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import io.strimzi.api.kafka.model.storage.EphemeralStorageBuilder;
import java.lang.Object;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplateBuilder;
import io.strimzi.api.kafka.model.storage.EphemeralStorage;
import java.util.Map;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.storage.PersistentClaimStorageBuilder;
import java.lang.Deprecated;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplate;
import java.lang.StringBuffer;
import io.strimzi.api.kafka.model.storage.EphemeralStorageFluent;
import io.strimzi.api.kafka.model.template.ZookeeperClusterTemplateFluent;

public interface ZookeeperClusterSpecFluent<A extends ZookeeperClusterSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildStorage instead.
 * @return The buildable object.
 */
@Deprecated public SingleVolumeStorage getStorage();
    public SingleVolumeStorage buildStorage();
    public A withStorage(SingleVolumeStorage storage);
    public Boolean hasStorage();
    public A withPersistentClaimStorage(PersistentClaimStorage persistentClaimStorage);
    public ZookeeperClusterSpecFluent.PersistentClaimStorageNested<A> withNewPersistentClaimStorage();
    public ZookeeperClusterSpecFluent.PersistentClaimStorageNested<A> withNewPersistentClaimStorageLike(PersistentClaimStorage item);
    public A withEphemeralStorage(EphemeralStorage ephemeralStorage);
    public ZookeeperClusterSpecFluent.EphemeralStorageNested<A> withNewEphemeralStorage();
    public ZookeeperClusterSpecFluent.EphemeralStorageNested<A> withNewEphemeralStorageLike(EphemeralStorage item);
    public A addToConfig(String key,Object value);
    public A addToConfig(Map<String,Object> map);
    public A removeFromConfig(String key);
    public A removeFromConfig(Map<String,Object> map);
    public Map<String,Object> getConfig();
    public A withConfig(Map<String,Object> config);
    public Boolean hasConfig();
    
/**
 * This method has been deprecated, please use method buildLogging instead.
 * @return The buildable object.
 */
@Deprecated public Logging getLogging();
    public Logging buildLogging();
    public A withLogging(Logging logging);
    public Boolean hasLogging();
    public A withExternalLogging(ExternalLogging externalLogging);
    public ZookeeperClusterSpecFluent.ExternalLoggingNested<A> withNewExternalLogging();
    public ZookeeperClusterSpecFluent.ExternalLoggingNested<A> withNewExternalLoggingLike(ExternalLogging item);
    public A withInlineLogging(InlineLogging inlineLogging);
    public ZookeeperClusterSpecFluent.InlineLoggingNested<A> withNewInlineLogging();
    public ZookeeperClusterSpecFluent.InlineLoggingNested<A> withNewInlineLoggingLike(InlineLogging item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecar instead.
 * @return The buildable object.
 */
@Deprecated public TlsSidecar getTlsSidecar();
    public TlsSidecar buildTlsSidecar();
    public A withTlsSidecar(TlsSidecar tlsSidecar);
    public Boolean hasTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> withNewTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> withNewTlsSidecarLike(TlsSidecar item);
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecar();
    public ZookeeperClusterSpecFluent.TlsSidecarNested<A> editOrNewTlsSidecarLike(TlsSidecar item);
    public int getReplicas();
    public A withReplicas(int replicas);
    public Boolean hasReplicas();
    public String getImage();
    public A withImage(String image);
    public Boolean hasImage();
    public A withNewImage(String arg1);
    public A withNewImage(StringBuilder arg1);
    public A withNewImage(StringBuffer arg1);
    public ResourceRequirements getResources();
    public A withResources(ResourceRequirements resources);
    public Boolean hasResources();
    
/**
 * This method has been deprecated, please use method buildLivenessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getLivenessProbe();
    public Probe buildLivenessProbe();
    public A withLivenessProbe(Probe livenessProbe);
    public Boolean hasLivenessProbe();
    public A withNewLivenessProbe(int initialDelaySeconds,int timeoutSeconds);
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> withNewLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> withNewLivenessProbeLike(Probe item);
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbe();
    public ZookeeperClusterSpecFluent.LivenessProbeNested<A> editOrNewLivenessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildReadinessProbe instead.
 * @return The buildable object.
 */
@Deprecated public Probe getReadinessProbe();
    public Probe buildReadinessProbe();
    public A withReadinessProbe(Probe readinessProbe);
    public Boolean hasReadinessProbe();
    public A withNewReadinessProbe(int initialDelaySeconds,int timeoutSeconds);
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> withNewReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> withNewReadinessProbeLike(Probe item);
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbe();
    public ZookeeperClusterSpecFluent.ReadinessProbeNested<A> editOrNewReadinessProbeLike(Probe item);
    
/**
 * This method has been deprecated, please use method buildJvmOptions instead.
 * @return The buildable object.
 */
@Deprecated public JvmOptions getJvmOptions();
    public JvmOptions buildJvmOptions();
    public A withJvmOptions(JvmOptions jvmOptions);
    public Boolean hasJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> withNewJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> withNewJvmOptionsLike(JvmOptions item);
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editOrNewJvmOptions();
    public ZookeeperClusterSpecFluent.JvmOptionsNested<A> editOrNewJvmOptionsLike(JvmOptions item);
    
/**
 * This method has been deprecated, please use method buildMetricsConfig instead.
 * @return The buildable object.
 */
@Deprecated public MetricsConfig getMetricsConfig();
    public MetricsConfig buildMetricsConfig();
    public A withMetricsConfig(MetricsConfig metricsConfig);
    public Boolean hasMetricsConfig();
    public A withJmxPrometheusExporterMetricsConfig(JmxPrometheusExporterMetrics jmxPrometheusExporterMetricsConfig);
    public ZookeeperClusterSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfig();
    public ZookeeperClusterSpecFluent.JmxPrometheusExporterMetricsConfigNested<A> withNewJmxPrometheusExporterMetricsConfigLike(JmxPrometheusExporterMetrics item);
    public A addToMetrics(String key,Object value);
    public A addToMetrics(Map<String,Object> map);
    public A removeFromMetrics(String key);
    public A removeFromMetrics(Map<String,Object> map);
    public Map<String,Object> getMetrics();
    public A withMetrics(Map<String,Object> metrics);
    public Boolean hasMetrics();
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public java.util.List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(java.util.List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public ZookeeperClusterTemplate getTemplate();
    public ZookeeperClusterTemplate buildTemplate();
    public A withTemplate(ZookeeperClusterTemplate template);
    public Boolean hasTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> withNewTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> withNewTemplateLike(ZookeeperClusterTemplate item);
    public ZookeeperClusterSpecFluent.TemplateNested<A> editTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> editOrNewTemplate();
    public ZookeeperClusterSpecFluent.TemplateNested<A> editOrNewTemplateLike(ZookeeperClusterTemplate item);

    public interface PersistentClaimStorageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PersistentClaimStorageFluent<ZookeeperClusterSpecFluent.PersistentClaimStorageNested<N>>{

        
    public N and();    public N endPersistentClaimStorage();
}
    public interface EphemeralStorageNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,EphemeralStorageFluent<ZookeeperClusterSpecFluent.EphemeralStorageNested<N>>{

        
    public N and();    public N endEphemeralStorage();
}
    public interface ExternalLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExternalLoggingFluent<ZookeeperClusterSpecFluent.ExternalLoggingNested<N>>{

        
    public N and();    public N endExternalLogging();
}
    public interface InlineLoggingNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InlineLoggingFluent<ZookeeperClusterSpecFluent.InlineLoggingNested<N>>{

        
    public N and();    public N endInlineLogging();
}
    public interface TlsSidecarNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TlsSidecarFluent<ZookeeperClusterSpecFluent.TlsSidecarNested<N>>{

        
    public N and();    public N endTlsSidecar();
}
    public interface LivenessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<ZookeeperClusterSpecFluent.LivenessProbeNested<N>>{

        
    public N and();    public N endLivenessProbe();
}
    public interface ReadinessProbeNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ProbeFluent<ZookeeperClusterSpecFluent.ReadinessProbeNested<N>>{

        
    public N and();    public N endReadinessProbe();
}
    public interface JvmOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JvmOptionsFluent<ZookeeperClusterSpecFluent.JvmOptionsNested<N>>{

        
    public N and();    public N endJvmOptions();
}
    public interface JmxPrometheusExporterMetricsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JmxPrometheusExporterMetricsFluent<ZookeeperClusterSpecFluent.JmxPrometheusExporterMetricsConfigNested<N>>{

        
    public N and();    public N endJmxPrometheusExporterMetricsConfig();
}
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ZookeeperClusterTemplateFluent<ZookeeperClusterSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}


}
